@@ -7,18 +7,18 @@
 #include <errno.h>
 #include <sys/stat.h>
 
-const char* FILE_NAME = "Sys/IO/Stat.c";
+static const char* FILE_NAME = "Sys/IO/Stat.c";
 
 int32_t SPVM__Sys__IO__Stat__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   // sizeof(struct stat) is maybe right, but Ubuntu/Linux 32bit doesn't work well in this setting.
   // So sizeof(struct stat) * 2 is allocated.
-  struct stat* st_stat = env->new_memory_stack(env, stack, sizeof(struct stat) * 2);
+  struct stat* st_stat = env->new_memory_block(env, stack, sizeof(struct stat) * 2);
   
-  void* obj_stat = env->new_pointer_object_by_name(env, stack, "Sys::IO::Stat", st_stat, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  void* obj_stat = env->new_pointer_object_by_name(env, stack, "Sys::IO::Stat", st_stat, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   stack[0].oval = obj_stat;
   
@@ -33,132 +33,103 @@ int32_t SPVM__Sys__IO__Stat__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   assert(st_stat);
   
-  env->free_memory_stack(env, stack, st_stat);
+  env->free_memory_block(env, stack, st_stat);
 
   env->set_pointer(env, stack, obj_stat, NULL);
   
   return 0;
 }
 
-int32_t SPVM__Sys__IO__Stat__stat_raw(SPVM_ENV* env, SPVM_VALUE* stack) {
-
-  int32_t e = 0;
+int32_t SPVM__Sys__IO__Stat__stat(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t error_id = 0;
   
   void* obj_path = stack[0].oval;
   if (!obj_path) {
-    return env->die(env, stack, "The $path must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$path must be defined.", __func__, FILE_NAME, __LINE__);
   }
   const char* path = env->get_chars(env, stack, obj_path);
   
   void* obj_stat = stack[1].oval;
   if (!obj_stat) {
-    return env->die(env, stack, "The $stat must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$stat must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   struct stat* stat_buf = env->get_pointer(env, stack, obj_stat);
   
-  errno = 0;
   int32_t status = stat(path, stat_buf);
-
+  
+  if (status == -1) {
+    const char* path = env->get_chars(env, stack, obj_path);
+    env->die(env, stack, "[System Error]stat failed:%s. $path is \"%s\".", path, env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+  }
+  
   stack[0].ival = status;
   
   return 0;
 }
 
-
-int32_t SPVM__Sys__IO__Stat__stat(SPVM_ENV* env, SPVM_VALUE* stack) {
-  void* obj_path = stack[0].oval;
+int32_t SPVM__Sys__IO__Stat__lstat(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  SPVM__Sys__IO__Stat__stat_raw(env, stack);
-  
-  int32_t status = stack[0].ival;
-
-  if (status == -1) {
-    const char* path = env->get_chars(env, stack, obj_path);
-    env->die(env, stack, "[System Error]stat failed:%s. The specified file is \"%s\"", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
-    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
-  }
-  
-  return 0;
-}
-
-int32_t SPVM__Sys__IO__Stat__lstat_raw(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  return env->die(env, stack, "lstat is not supported on this system(defined(_WIN32))", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "lstat is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
 #else
 
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_path = stack[0].oval;
   if (!obj_path) {
-    return env->die(env, stack, "The $path must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$path must be defined.", __func__, FILE_NAME, __LINE__);
   }
   const char* path = env->get_chars(env, stack, obj_path);
   
   void* obj_lstat = stack[1].oval;
   if (!obj_lstat) {
-    return env->die(env, stack, "The $lstat must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$lstat must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   struct stat* stat_buf = env->get_pointer(env, stack, obj_lstat);
   
-  errno = 0;
   int32_t status = lstat(path, stat_buf);
   
+  if (status == -1) {
+    const char* path = env->get_chars(env, stack, obj_path);
+    env->die(env, stack, "[System Error]lstat failed:%s. $path is \"%s\".", path, env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
+    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+  }
+  
   stack[0].ival = status;
   
   return 0;
 #endif
-}
 
-
-int32_t SPVM__Sys__IO__Stat__lstat(SPVM_ENV* env, SPVM_VALUE* stack) {
-  void* obj_path = stack[0].oval;
-  
-  SPVM__Sys__IO__Stat__lstat_raw(env, stack);
-  
-  int32_t status = stack[0].ival;
-
-  if (status == -1) {
-    const char* path = env->get_chars(env, stack, obj_path);
-    env->die(env, stack, "[System Error]lstat failed:%s. The specified file is \"%s\"", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
-    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
-  }
-  
   return 0;
 }
 
-int32_t SPVM__Sys__IO__Stat__fstat_raw(SPVM_ENV* env, SPVM_VALUE* stack) {
-
-  int32_t e = 0;
+int32_t SPVM__Sys__IO__Stat__fstat(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t error_id = 0;
   
   int32_t fd = stack[0].ival;
   
   void* obj_stat = stack[1].oval;
   
   if (!obj_stat) {
-    return env->die(env, stack, "The $stat must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$stat must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   struct stat* stat_buf = env->get_pointer(env, stack, obj_stat);
   
   int32_t status = fstat(fd, stat_buf);
-
-  stack[0].ival = status;
   
-  return 0;
-}
-
-int32_t SPVM__Sys__IO__Stat__fstat(SPVM_ENV* env, SPVM_VALUE* stack) {
-  SPVM__Sys__IO__Stat__fstat_raw(env, stack);
-  
-  int32_t status = stack[0].ival;
-
   if (status == -1) {
-    env->die(env, stack, "[System Error]fstat failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]fstat failed:%s.", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
+  stack[0].ival = status;
+  
   return 0;
 }
 
@@ -218,7 +189,7 @@ int32_t SPVM__Sys__IO__Stat__st_size(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__Stat__st_blksize(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "The \"st_blksize\" method in the class \"Sys::IO::Stat\" is not supported on this system", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "The \"st_blksize\" method in the class \"Sys::IO::Stat\" is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   void* obj_stat = stack[0].oval;
@@ -233,7 +204,7 @@ int32_t SPVM__Sys__IO__Stat__st_blksize(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__Stat__st_blocks(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "The \"st_blocks\" method in the class \"Sys::IO::Stat\" is not supported on this system", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "The \"st_blocks\" method in the class \"Sys::IO::Stat\" is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   void* obj_stat = stack[0].oval;
@@ -326,10 +297,10 @@ int32_t SPVM__Sys__IO__Stat__st_ctime(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__Stat__st_atim_tv_nsec(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "The st_atim_tv_nsec method in the Sys::IO::Stat is not supported on this system(defined(_WIN32))", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "The st_atim_tv_nsec method in the Sys::IO::Stat is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #elif defined(__solaris) || defined(__sun)
-  env->die(env, stack, "The st_atim_tv_nsec method in the Sys::IO::Stat is not supported on this system(__solaris or __sun)", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "The st_atim_tv_nsec method in the Sys::IO::Stat is not supported in this system(__solaris or __sun).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   void* obj_stat = stack[0].oval;
@@ -348,10 +319,10 @@ int32_t SPVM__Sys__IO__Stat__st_atim_tv_nsec(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__Stat__st_mtim_tv_nsec(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "The st_mtim_tv_nsec method in the Sys::IO::Stat is not supported on this system(defined(_WIN32))", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "The st_mtim_tv_nsec method in the Sys::IO::Stat is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #elif defined(__solaris) || defined(__sun)
-  env->die(env, stack, "The st_mtim_tv_nsec method in the Sys::IO::Stat is not supported on this system(__solaris or __sun)", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "The st_mtim_tv_nsec method in the Sys::IO::Stat is not supported in this system(__solaris or __sun).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   void* obj_stat = stack[0].oval;
@@ -370,10 +341,10 @@ int32_t SPVM__Sys__IO__Stat__st_mtim_tv_nsec(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__Stat__st_ctim_tv_nsec(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "The st_ctim_tv_nsec method in the Sys::IO::Stat is not supported on this system(defined(_WIN32))", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "The st_ctim_tv_nsec method in the Sys::IO::Stat is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #elif defined(__solaris) || defined(__sun)
-  env->die(env, stack, "The st_ctim_tv_nsec method in the Sys::IO::Stat is not supported on this system(__solaris or __sun)", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "The st_ctim_tv_nsec method in the Sys::IO::Stat is not supported in this system(__solaris or __sun).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   void* obj_stat = stack[0].oval;
