@@ -1,15 +1,6 @@
 // Copyright (c) 2023 Yuki Kimoto
 // MIT License
 
-#ifdef __linux__
-  // Enable X/Open System Interfaces (SUSv4) functions and POSIX.1-2008 standard functions
-  #define _XOPEN_SOURCE 700
-
-  // Enable BSD and System V extensions
-  #define _DEFAULT_SOURCE
-#endif
-
-
 // Windows 8.1+
 #define _WIN32_WINNT 0x0603
 
@@ -76,10 +67,10 @@ static const char* socket_strerror(SPVM_ENV* env, SPVM_VALUE* stack, int32_t err
 int32_t SPVM__Sys__Poll__poll(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_fds = stack[0].oval;
   
-  int32_t nfds = stack[1].ival;
-  
   struct pollfd* fds = env->get_pointer(env, stack, obj_fds);
   
+  int32_t nfds = stack[1].ival;
+  
   int32_t timeout = stack[2].ival;
   
 #if defined(_WIN32)
@@ -89,7 +80,7 @@ int32_t SPVM__Sys__Poll__poll(SPVM_ENV* env, SPVM_VALUE* stack) {
 #endif
 
   if (ready_count == -1) {
-    env->die(env, stack, "[System Error]poll() failed(%d: %s)", __func__, FILE_NAME, __LINE__, socket_errno(), socket_strerror(env, stack, socket_errno(), 0));
+    env->die(env, stack, "[System Error]poll failed: %s", socket_strerror(env, stack, socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
