@@ -6,16 +6,16 @@
 
 #include <assert.h>
 
-const char* FILE_NAME = "Sys/Socket/In6_addr.c";
+static const char* FILE_NAME = "Sys/Socket/In6_addr.c";
 
 int32_t SPVM__Sys__Socket__In6_addr__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
-  struct in6_addr* address = env->new_memory_stack(env, stack, sizeof(struct in6_addr));
-
-  void* obj_address = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In6_addr", address, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  struct in6_addr* address = env->new_memory_block(env, stack, sizeof(struct in6_addr));
+  
+  void* obj_address = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In6_addr", address, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   stack[0].oval = obj_address;
   
@@ -30,7 +30,7 @@ int32_t SPVM__Sys__Socket__In6_addr__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   assert(address);
   
-  env->free_memory_stack(env, stack, address);
+  env->free_memory_block(env, stack, address);
   env->set_pointer(env, stack, obj_address, NULL);
   
   return 0;
@@ -58,17 +58,17 @@ int32_t SPVM__Sys__Socket__In6_addr__set_s6_addr(SPVM_ENV* env, SPVM_VALUE* stac
   struct in6_addr* address = env->get_pointer(env, stack, obj_address);
   
   assert(address);
-
+  
   void* obj_s6_addr = stack[1].oval;
   
   if (!obj_s6_addr) {
-    return env->die(env, stack, "The address must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The address must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t s6_addr_length = env->length(env, stack, obj_s6_addr);
   
   if (!(s6_addr_length < 16)) {
-    return env->die(env, stack, "The length of the address must be less than 16", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The length of the address must be less than 16.", __func__, FILE_NAME, __LINE__);
   }
   
   const char* chp_s6_addr = env->get_chars(env, stack, obj_s6_addr);
