@@ -6,19 +6,19 @@
 
 #include <assert.h>
 
-const char* FILE_NAME = "Sys/Socket/Ip_mreq_source.c";
+static const char* FILE_NAME = "Sys/Socket/Ip_mreq_source.c";
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__new(SPVM_ENV* env, SPVM_VALUE* stack) {
 #ifdef __OpenBSD__
-  env->die(env, stack, "The new method in the Sys::Socket::Ip_mreq_sourceclock_nanosleep is not supported on this system(__OpenBSD__)", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "The new method is not supported in this system(__OpenBSD__).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
-  int32_t e = 0;
+  int32_t error_id = 0;
   
-  struct ip_mreq_source* multi_request_source = env->new_memory_stack(env, stack, sizeof(struct ip_mreq_source));
+  struct ip_mreq_source* multi_request_source = env->new_memory_block(env, stack, sizeof(struct ip_mreq_source));
 
-  void* obj_multi_request_source = env->new_pointer_object_by_name(env, stack, "Sys::Socket::Ip_mreq_source", multi_request_source, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  void* obj_multi_request_source = env->new_pointer_object_by_name(env, stack, "Sys::Socket::Ip_mreq_source", multi_request_source, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   stack[0].oval = obj_multi_request_source;
   
@@ -29,7 +29,7 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__new(SPVM_ENV* env, SPVM_VALUE* stack)
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
 #ifdef __OpenBSD__
-  env->die(env, stack, "The new method in the Sys::Socket::Ip_mreq_sourceclock_nanosleep is not supported on this system(__OpenBSD__)", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "The DESTROY method is not supported in this system(__OpenBSD__).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   void* obj_multi_request_source = stack[0].oval;
@@ -38,7 +38,7 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__DESTROY(SPVM_ENV* env, SPVM_VALUE* st
   
   assert(multi_request_source);
   
-  env->free_memory_stack(env, stack, multi_request_source);
+  env->free_memory_block(env, stack, multi_request_source);
   env->set_pointer(env, stack, obj_multi_request_source, NULL);
   
   return 0;
@@ -47,22 +47,22 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__DESTROY(SPVM_ENV* env, SPVM_VALUE* st
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__imr_multiaddr(SPVM_ENV* env, SPVM_VALUE* stack) {
 #ifdef __OpenBSD__
-  env->die(env, stack, "The new method in the Sys::Socket::Ip_mreq_sourceclock_nanosleep is not supported on this system(__OpenBSD__)", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "The imr_multiaddr method is not supported in this system(__OpenBSD__).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_self = stack[0].oval;
   
   struct ip_mreq_source* multi_request_source = env->get_pointer(env, stack, obj_self);
   
   struct in_addr address = multi_request_source->imr_multiaddr;
-
-  struct in_addr* address_ret = env->new_memory_stack(env, stack, sizeof(struct in_addr));
+  
+  struct in_addr* address_ret = env->new_memory_block(env, stack, sizeof(struct in_addr));
   *address_ret = address;
-
-  void* obj_address_ret = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In_addr", address_ret, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  
+  void* obj_address_ret = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In_addr", address_ret, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   stack[0].oval = obj_address_ret;
   
@@ -72,7 +72,7 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__imr_multiaddr(SPVM_ENV* env, SPVM_VAL
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__set_imr_multiaddr(SPVM_ENV* env, SPVM_VALUE* stack) {
 #ifdef __OpenBSD__
-  env->die(env, stack, "The set_imr_multiaddr method in the Sys::Socket::Ip_mreq_sourceclock_nanosleep is not supported on this system(__OpenBSD__)", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "The set_imr_multiaddr method is not supported in this system(__OpenBSD__).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   void* obj_self = stack[0].oval;
@@ -81,7 +81,7 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__set_imr_multiaddr(SPVM_ENV* env, SPVM
   
   void* obj_address = stack[1].oval;
   struct in_addr* address = env->get_pointer(env, stack, obj_address);
-
+  
   multi_request_source->imr_multiaddr = *address;
   
   return 0;
@@ -90,10 +90,10 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__set_imr_multiaddr(SPVM_ENV* env, SPVM
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__imr_interface(SPVM_ENV* env, SPVM_VALUE* stack) {
 #ifdef __OpenBSD__
-  env->die(env, stack, "The imr_interface method in the Sys::Socket::Ip_mreq_sourceclock_nanosleep is not supported on this system(__OpenBSD__)", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "The imr_interface method is not supported in this system(__OpenBSD__).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_self = stack[0].oval;
   
@@ -101,11 +101,11 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__imr_interface(SPVM_ENV* env, SPVM_VAL
   
   struct in_addr address = multi_request_source->imr_interface;
 
-  struct in_addr* address_ret = env->new_memory_stack(env, stack, sizeof(struct in_addr));
+  struct in_addr* address_ret = env->new_memory_block(env, stack, sizeof(struct in_addr));
   *address_ret = address;
-
-  void* obj_address_ret = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In_addr", address_ret, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  
+  void* obj_address_ret = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In_addr", address_ret, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   stack[0].oval = obj_address_ret;
   
@@ -115,7 +115,7 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__imr_interface(SPVM_ENV* env, SPVM_VAL
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__set_imr_interface(SPVM_ENV* env, SPVM_VALUE* stack) {
 #ifdef __OpenBSD__
-  env->die(env, stack, "The set_imr_interface method in the Sys::Socket::Ip_mreq_sourceclock_nanosleep is not supported on this system(__OpenBSD__)", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "The set_imr_interface method is not supported in this system(__OpenBSD__).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   void* obj_self = stack[0].oval;
@@ -124,7 +124,7 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__set_imr_interface(SPVM_ENV* env, SPVM
   
   void* obj_address = stack[1].oval;
   struct in_addr* address = env->get_pointer(env, stack, obj_address);
-
+  
   multi_request_source->imr_interface = *address;
   
   return 0;
@@ -133,22 +133,22 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__set_imr_interface(SPVM_ENV* env, SPVM
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__imr_sourceaddr(SPVM_ENV* env, SPVM_VALUE* stack) {
 #ifdef __OpenBSD__
-  env->die(env, stack, "The imr_sourceaddr method in the Sys::Socket::Ip_mreq_sourceclock_nanosleep is not supported on this system(__OpenBSD__)", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "The imr_sourceaddr method is not supported in this system(__OpenBSD__).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_self = stack[0].oval;
   
   struct ip_mreq_source* multi_request_source = env->get_pointer(env, stack, obj_self);
   
   struct in_addr address = multi_request_source->imr_sourceaddr;
-
-  struct in_addr* address_ret = env->new_memory_stack(env, stack, sizeof(struct in_addr));
+  
+  struct in_addr* address_ret = env->new_memory_block(env, stack, sizeof(struct in_addr));
   *address_ret = address;
-
-  void* obj_address_ret = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In_addr", address_ret, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  
+  void* obj_address_ret = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In_addr", address_ret, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   stack[0].oval = obj_address_ret;
   
@@ -158,7 +158,7 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__imr_sourceaddr(SPVM_ENV* env, SPVM_VA
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__set_imr_sourceaddr(SPVM_ENV* env, SPVM_VALUE* stack) {
 #ifdef __OpenBSD__
-  env->die(env, stack, "The set_imr_sourceaddr method in the Sys::Socket::Ip_mreq_sourceclock_nanosleep is not supported on this system(__OpenBSD__)", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "The set_imr_sourceaddr method is not supported in this system(__OpenBSD__).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   void* obj_self = stack[0].oval;
@@ -167,7 +167,7 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__set_imr_sourceaddr(SPVM_ENV* env, SPV
   
   void* obj_address = stack[1].oval;
   struct in_addr* address = env->get_pointer(env, stack, obj_address);
-
+  
   multi_request_source->imr_sourceaddr = *address;
   
   return 0;
